package dev.fitko.fitconnect.api.domain.validation;

import dev.fitko.fitconnect.api.domain.model.event.authtags.AuthenticationTags;
import dev.fitko.fitconnect.api.exceptions.ValidationException;
import lombok.Getter;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

@Getter
public class ValidationContext {
    private final List<ValidationResult> validationResults;
    private final UUID destinationId;
    private final UUID caseId;
    private final AuthenticationTags authenticationTags;

    boolean validateAuthTags;

    public ValidationContext(final UUID destinationId, final UUID caseId) {
        this.destinationId = destinationId;
        this.caseId = caseId;
        this.authenticationTags = null;
        this.validateAuthTags = false;
        this.validationResults = new ArrayList<>();
    }

    public ValidationContext(final UUID destinationId, final UUID caseId, final AuthenticationTags authenticationTags) {
        this.destinationId = destinationId;
        this.caseId = caseId;
        this.authenticationTags = authenticationTags;
        this.validateAuthTags = true;
        this.validationResults = new ArrayList<>();
    }

    public void addResult(final ValidationResult validationResult) {
        if (validationResult.hasError()) {
            this.validationResults.add(validationResult);
        }
    }

    public void addResult(final boolean test, final String message) {
        if (!test) {
            addResult(ValidationResult.error(new ValidationException(message)));
        }
    }

    public void addError(final String message) {
        addResult(ValidationResult.error(new ValidationException(message)));
    }

    public void addError(final Exception exception) {
        addResult(ValidationResult.error(new ValidationException(exception.getMessage(), exception)));
    }

    public UUID getDestinationId() {
        return this.destinationId;
    }

    public UUID getCaseId() {
        return this.caseId;
    }

    public AuthenticationTags getAuthenticationTags() {
        return this.authenticationTags;
    }

    public boolean validateAuthTags(){
        return this.validateAuthTags;
    }

}
